----------------------------------------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------------------------------------

--	File:		MapOptions.lua
--	Description:	 Custom MapOptions file that makes possible to set up variable options before game starts, like ModOptions.lua
--	Author:	SirArtturi, Lurker, Smoth


----------------------------------------------------------------------------------------------------------------------------------------------
----------------------------------------------------------------------------------------------------------------------------------------------

--[[	OPTION DEFINITION FILES

	CustomMapOptions.lua
	- belongs in the map archive
	- options that get used by LuaGaia

	CustomModOptions.lua
	- belongs in the mod archive
	- options that get used by LuaRules

--]]

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

--	NOTES:
--	- using an enumerated table lets you specify the options order

--
--	These keywords must be lowercase for LuaParser to read them.
--
--	key:			the string used in the script.txt
--	name:		 the displayed name
--	desc:		 the description (could be used as a tooltip)
--	type:		 the option type
--	def:			the default value
--	min:			minimum value for number options
--	max:			maximum value for number options
--	step:		 quantization step, aligned to the def value
--	maxlen:	 the maximum string length for string options
--	items:		array of item strings for list options
--	scope:		'all', 'player', 'team', 'allyteam'			<<< not supported yet >>>
--

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

local options = {

	{
		key = 'Atmosphere',
		name = 'Atmosphere settings',
		desc = 'Weather and time',
		type = 'section',
	},
		
	{
		key="alt",
		name="Time of day",
		desc="Night or day?",
		type="list",
		def="0",
		section= 'Atmosphere',
		items = {
			{ key = "0", name = "Day", desc = "Day Time"	},
			{ key = "1", name = "Night", desc = "Night Time" }
		},
	},
	-- {
		-- key = 'fog',
		-- name = 'want fog?',
		-- desc = "enable a dense fog(can slow older hardware)",
		-- type = 'bool',
		-- section = 'Atmosphere',
		-- def = true,
	-- },
	-- {
		-- key="wc",
		-- name="Weather conditions",
		-- desc="snowing",
		-- type="list",
		-- def="1",
		-- section= 'Atmosphere',
		-- items = {
			-- { key = "0", name = "None", desc = "no weather"	},
			-- { key = "1", name = "Snowing", desc = "snowy day" }
		-- },
	-- },

	-- {
		-- key = 'inv',
		-- name = 'Inverts the world',
		-- desc = "flips things",
		-- type = 'bool',
		-- section = 'Terrain',
		-- def = false,
	-- },
	
	{
		key="dry",
		name="Wetness",
		desc="How wet do you like it?",
		type="list",
		def="0",
		section= 'Terrain',
		items = {
			{ key = "0", name = "Wet", desc = "a river runs through"  },
			{ key = "1", name = "Dry", desc = "no water" }
		},
	},	
	-- {
		-- key		= 'metal',
		-- name	 = 'Metal Production',
		-- desc	 = 'Metal production levels - How much metal is produced per second',
		-- type	 = 'list',
		-- def		= '1',
		-- items	= {
			-- { key = '0', name = "Low", desc = "Low metal density - for smaller teams" },
			-- { key = '1', name = "Normal", desc = "Default metal density" },
			-- { key = '2', name = "High", desc = "High metal density - for big teams" },
			 -- },
	-- },

	-- {
		-- key		= 'wind',
		-- name	 = 'Wind Speed',
		-- desc	 = 'How strong wind will blow',
		-- type	 = 'list',
		-- def		= '1',
		-- items	= {
			-- { key = '0', name = "Low", desc = "Weak wind speed - for smaller teams" },
			-- { key = '1', name = "Normal", desc = "Default wind speed" },
			-- { key = '2', name = "High", desc = "High wind speed - for big teams" },
		 -- },
	-- },

	-- {
		-- key		= 'tidal',
		-- name	 = 'Tidal Strenght',
		-- desc	 = 'Tidal energy levels - How much energy is produced via tidal generators',
		-- type	 = 'list',
		-- def		= '1',
		-- items	= {
			-- { key = '0', name = "Low", desc = "Weak tidals - for smaller teams" },
			-- { key = '1', name = "Normal", desc = "Default tidals" },
			-- { key = '2', name = "High", desc = "Strong tidals - for big teams" },
		 -- },
	-- },
--	{
--	key		= 'extractorradius',
--	name	 = 'Extractor Radius',
--	desc	 = 'Sets the metal extractor radius',
-- 	type	 = 'number',
--	def		= 100,
--	min		= 1,
--	max		= 10000,
--	section= 'Atmosphere',
--	step	 = 1,	-- quantization is aligned to the def value
			-- (step <= 0) means that there is no quantization
--	},
}

return options